<?php

/**
 * WordPress admin Options class
 *
 * @author MesajPaneliSMS
 */
class MesajPaneliOptions {

    private $settings_api;

    function __construct() {

        $this->settings_api = new MesajPaneli_Settings_API();

        add_action('admin_init', [ $this, 'admin_init' ]);
        add_action('admin_menu', [ $this, 'admin_menu' ]);
    }

    /**
     * Admin init hook
     *
     * @return void
     */
    function admin_init() {

        //set the settings
        $this->settings_api->set_sections($this->get_settings_sections());
        $this->settings_api->set_fields($this->get_settings_fields());

        //initialize settings
        $this->settings_api->admin_init();
    }

    /**
     * Get All settings Field
     *
     * @return array
     */
    function get_settings_sections() {
        $sections = [
            [
                'id'    => 'mesajpanelisms_general',
                'title' => __('Mesaj Ayarları', 'MesajPaneliSMS')
            ],
            [
                'id'    => 'mesajpanelisms_gateway',
                'title' => __('MesajPaneli Ayarları', 'MesajPaneliSMS')
            ],

            [
                'id'    => 'mesajpanelisms_message',
                'title' => __('Mesaj İçeriği', 'MesajPaneliSMS')
            ]
        ];

        return apply_filters('mesajpanelisms_settings_sections', $sections);
    }

    /**
     * Returns all the settings fields
     *
     * @return array settings fields
     */
    function get_settings_fields() {

        $order_statuses = $this->order_statuses();
        $buyer_message  = "[order_id] nolu siparişiniz, [order_status] durumundadır. \nBizi seçtiğiniz için teşekkürler!";
        $admin_message  = "Yeni bir sipariş var.\n[order_id] nolu siparişin durumu : [order_status]\n";
        $order_statuses = $this->order_statuses();
        $order_array    = [];

        foreach ($order_statuses as $key => $value) {
            $order_array[] = [
                'name'    => 'order_' . $key,
                'label'   => __('Ürün durumlarında SMS gönder', 'MesajPaneliSMS'),
                'desc'    => __('Ürün durumu <b>' . $value . '</b> olduğunda SMS gönderir.', 'MesajPaneliSMS'),
                'type'    => 'textarea',
                'default' => __($buyer_message, 'MesajPaneliSMS')
            ];
        }

        $settings_fields = [

            'mesajpanelisms_general' => apply_filters('mesajpanelisms_general_settings', [
                [
                    'name'  => 'enable_notification',
                    'label' => __('Yeni sipariş için SMS', 'MesajPaneliSMS'),
                    'desc'  => __('Aktif edilirse yeni siparişler için SMS göndermeyi aktif eder.', 'MesajPaneliSMS'),
                    'type'  => 'checkbox',
                ],
                [
                    'name'    => 'admin_notification',
                    'label'   => __('Admin için SMS', 'MesajPaneliSMS'),
                    'desc'    => __('Aktif edilirse yeni siparişlerde (durumu işleniyor veya beklemede olan siparişlerde) admine mesaj göndermeyi aktif eder.', 'MesajPaneliSMS'),
                    'type'    => 'checkbox',
                    'default' => 'on'
                ],
                [
                    'name'  => 'force_sms',
                    'label' => __('SMS Gönderme isteğe bağlı değildir', 'MesajPaneliSMS'),
                    'desc'  => __('Aktif edilirse seçeneğe bağlı olmadan SMS gönderimini aktif eder, satın alma ekranında SMS alma seçeneğini göstermez.', 'MesajPaneliSMS'),
                    'type'  => 'checkbox',
                ],
                [
                    'name'  => 'buyer_notification',
                    'label' => __('Satın almada SMS seçeneği göster', 'MesajPaneliSMS'),
                    'desc'  => __('Aktif edilirse satın alma ekranında SMS alma seçeneği gösterir.', 'MesajPaneliSMS'),
                    'type'  => 'checkbox',
                ],
                [
                    'name'    => 'force_buyer_notification',
                    'label'   => __('SMS seçeneğine zorla', 'MesajPaneliSMS'),
                    'desc'    => __('Aktif edilirse SMS ile bilgilendirme seçeneği zorunlu olur.', 'MesajPaneliSMS'),
                    'type'    => 'select',
                    'default' => 'no',
                    'options' => [
                        'yes' => 'Evet',
                        'no'  => 'Hayır'
                    ]
                ],
                [
                    'name'    => 'buyer_notification_text',
                    'label'   => __('SMS seçeneği yazısı', 'MesajPaneliSMS'),
                    'desc'    => __('Satın alma ekranında SMS seçeneğinin yanında çıkacak yazı ', 'MesajPaneliSMS'),
                    'type'    => 'textarea',
                    'default' => 'Ürün durumlarını bana mesaj ile bildir.'
                ],
                [
                    'name'    => 'order_status',
                    'label'   => __('Ürün durumu değişimi ', 'MesajPaneliSMS'),
                    'desc'    => __('Ürün durumu değiştiğinde SMS gönderir.', 'MesajPaneliSMS'),
                    'type'    => 'multicheck',
                    'options' => $order_statuses
                ]
            ]),

            /*'mesajpanelisms_gateway' => apply_filters( 'mesajpanelisms_gateway_settings',  array(
                array(
                    'name' => 'sms_gateway',
                    'label' => __( 'Select your Gateway', 'MesajPaneliSMS' ),
                    'desc' => __( 'Select your sms gateway', 'MesajPaneliSMS' ),
                    'type' => 'select',
                    'default' => '-1',
                    'options' => $this->get_sms_gateway()
                ),
            ) ),*/

            'mesajpanelisms_message' => apply_filters('mesajpanelisms_message_settings', array_merge([
                    [
                        'name'  => 'sms_admin_phone',
                        'label' => __('Admin Gsm numarası', 'MesajPaneliSMS'),
                        'desc'  => __('<br>Admine SMS ayarları aktifse mesaj gönderilecek numara.', 'MesajPaneliSMS'),
                        'type'  => 'text'
                    ],
                    [
                        'name'    => 'admin_sms_body',
                        'label'   => __('Admin SMS içeriği', 'MesajPaneliSMS'),
                        'desc'    => __(' Admine gidecek SMS\'i düzenleyebilirsiniz. Kullanabileceğiniz değişkenler; <code>[order_id]</code> , <code>[order_status]</code> , <code>[buyer_number]</code>', 'MesajPaneliSMS'),
                        'type'    => 'textarea',
                        'default' => __($admin_message, 'MesajPaneliSMS')
                    ],
                    [
                        'name'  => 'sms_hint',
                        'label' => __('Kullanılabilecek değişkenler ', 'MesajPaneliSMS'),
                        'desc'  => __('Ürün durumları değiştiğinde kullanabileceğiniz değişkenler; <code>[order_id]</code> , <code>[order_status]</code> <br> Kargo durumları için yith ile ortak çalışan değişkenler; <code>[ywot_carrier_name]</code>,<code>[ywot_pick_up_date]</code>,<code>[ywot_tracking_code]</code>', 'MesajPaneliSMS'),
                        'type'  => 'html',
                    ],
                ], $order_array)
            ),
        ];

        return apply_filters('mesajpanelisms_settings_
            section_content', $settings_fields);
    }

    public function order_statuses() {

        $status_posts = get_posts([
            'posts_per_page' => -1,
            'post_type'      => 'yith-wccos-ostatus',
            'post_status'    => 'publish'
        ]);

        foreach ($status_posts as $sp) {
            $statuses[ get_post_meta($sp->ID, 'slug', true) ] = $sp->post_title;
        }

        $default_statuses = [
            'pending'    => __('Ödeme Bekliyor', 'MesajPaneliSMS'),
            'processing' => __('İşleniyor', 'MesajPaneliSMS'),
            'on-hold'    => __('Beklemede', 'MesajPaneliSMS'),
            'completed'  => __('Tamamlandı', 'MesajPaneliSMS'),
            'cancelled'  => __('İptal Edildi', 'MesajPaneliSMS'),
            'refunded'   => __('İade Edildi', 'MesajPaneliSMS'),
            'failed'     => __('Başarısız', 'MesajPaneliSMS')
        ];

        if (!empty($statuses)) {
            $order_statuses = array_merge($statuses, $default_statuses);

            return $order_statuses;
        }

        return $default_statuses;
    }

    /**
     * Admin Menu CB
     *
     * @return void
     */
    function admin_menu() {
        add_menu_page(__('MesajPaneli SMS', 'mesajpaneli'), __('MesajPaneli SMS', 'MesajPaneliSMS'), 'manage_options', 'sat-order-sms-notification-settings', [
            $this,
            'plugin_page'
        ], plugins_url('MesajPaneliSMS/admin/images/im-icon.png'));
    }

    /**
     * Loaded Plugin page
     *
     * @return void
     */
    function plugin_page() {
        echo '<div class="wrap">';

        $this->settings_api->show_navigation();
        $this->settings_api->show_forms();

        echo '</div>';
    }

    /**
     * Get all the pages
     *
     * @return array page names with key value pairs
     */
    function get_pages() {
        $pages         = get_pages();
        $pages_options = [];
        if ($pages) {
            foreach ($pages as $page) {
                $pages_options[ $page->ID ] = $page->post_title;
            }
        }

        return $pages_options;
    }

    /**
     * Get SMS Gateway settings
     *
     * @return array
     */
    function get_sms_gateway() {
        $gateway = [
            'MesajPaneli' => __('MesajPaneli', 'MesajPaneliSMS'),
        ];

        return apply_filters('mesajpanelisms_sms_gateway', $gateway);
    }

}

function getOriginatedBalance($api_username, $api_password) {

    $data = "data=" . base64_encode(json_encode([ 'user' => [ 'name' => $api_username, 'pass' => $api_password ] ]));

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, 'http://api.smsvitrini.com/json_api/login');
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_HEADER, 0);
    curl_setopt($ch, CURLOPT_TIMEOUT, 120);

    $result   = curl_exec($ch);
    $userInfo = json_decode(base64_decode($result), true);

    if ($userInfo['status']) {
        return $userInfo['userData']['orjinli']; # baslikli kredi
    }

    return 'Auth Error';
}

function getNumericBalance($api_username, $api_password) {

    $data = "data=" . base64_encode(json_encode([ 'user' => [ 'name' => $api_username, 'pass' => $api_password ] ]));

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, 'http://api.smsvitrini.com/json_api/login');
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_HEADER, 0);
    curl_setopt($ch, CURLOPT_TIMEOUT, 120);

    $result   = curl_exec($ch);
    $userInfo = json_decode(base64_decode($result), true);

    if ($userInfo['status']) {
        return $userInfo['userData']['sistem_kredi']; # numerik kredi
    }

    return 'Auth Error';
}

function getDomain($api_username, $api_password) {

    $domain = $_SERVER['HTTP_HOST'];
    $data   = "data=" . base64_encode(json_encode([
            'user' => [ 'name' => $api_username, 'pass' => $api_password ],
            'site' => $domain
        ]));

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, 'http://api.smsvitrini.com/json_api/userDomains/isActiveUserDomain');
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_HEADER, 0);
    curl_setopt($ch, CURLOPT_TIMEOUT, 120);

    $result   = curl_exec($ch);
    $siteInfo = json_decode(base64_decode($result), true);

    if (!$siteInfo['siteInfo']) {
        return 'Bu MesajPaneli kullanıcısına ait kayıtlı siteler arasında bu site bulunmamaktadır. Lütfen plugini kullanacağınız tüm siteleri sisteme giriniz.';
    }

    return true;
}

function mesajpanelisms_settings_field_gateway() {

    $MesajPaneli_username   = mesajpanelisms_get_option('MesajPaneli_username', 'mesajpanelisms_gateway', '');
    $MesajPaneli_password   = mesajpanelisms_get_option('MesajPaneli_password', 'mesajpanelisms_gateway', '');
    $MesajPaneli_originator = mesajpanelisms_get_option('MesajPaneli_originator', 'mesajpanelisms_gateway', '');

    $balance   = getOriginatedBalance($MesajPaneli_username, $MesajPaneli_password);
    $Nbalance  = getNumericBalance($MesajPaneli_username, $MesajPaneli_password);
    $getdomain = getDomain($MesajPaneli_username, $MesajPaneli_password);

    if (!$balance) {
        $MesajPaneli_helper = sprintf('Mesaj gönderebilmek için giriş bilgileriniz doldurun. Eğer bilmiyorsanız <a href="%s" target="_blank">%s</a> bilgi alabilirsiniz.', 'https://www.smsvitrini.com', 'SMS Vitrini Mesaj Paneli\'nden');
    }
    else {
        $MesajPaneli_helper = sprintf('Mevcut başlıklı krediniz :' . $balance . ', numerik krediniz :' . $Nbalance . '  <a target="_blank" href="https://www.smsvitrini.com/">SMS Satın Al!</a>');
    }
    ?>

    <?php do_action('mesajpanelisms_gateway_settings_options_before'); ?>

    <div class="MesajPaneli_wrapper">
        <hr>
        <p style="margin-top:15px; margin-bottom:0px; padding-left: 20px; font-style: italic; font-size: 14px; color:red;">
            <strong><?php _e($MesajPaneli_helper, 'MesajPaneliSMS'); ?></strong>
        </p>
        <p style="margin-top:15px; margin-bottom:0px; padding-left: 20px; font-style: italic; font-size: 14px; ">
            <strong><?php _e($MesajPaneli_helper, 'MesajPaneliSMS'); ?></strong>
        </p>
        <table class="form-table">
            <tr valign="top">
                <th scrope="row"><?php _e('Kullanıcı Adı', 'MesajPaneliSMS') ?></th>
                <td>
                    <input type="text" name="mesajpanelisms_gateway[MesajPaneli_username]"
                           id="mesajpanelisms_gateway[MesajPaneli_username]" value="<?php echo $MesajPaneli_username; ?>">
                    <span><?php _e('', 'MesajPaneliSMS'); ?></span>
                </td>
            </tr>

            <tr valign="top">
                <th scrope="row"><?php _e('Şifre', 'MesajPaneliSMS') ?></th>
                <td>
                    <input type="password" name="mesajpanelisms_gateway[MesajPaneli_password]"
                           id="mesajpanelisms_gateway[MesajPaneli_password]" value="<?php echo $MesajPaneli_password; ?>">
                    <span><?php _e('', 'MesajPaneliSMS'); ?></span>
                </td>
            </tr>

            <tr valign="top">
                <th scrope="row"><?php _e('Başlık', 'MesajPaneliSMS') ?></th>
                <td>
                    <input type="text" name="mesajpanelisms_gateway[MesajPaneli_originator]"
                           id="mesajpanelisms_gateway[MesajPaneli_originator]" value="<?php echo $MesajPaneli_originator; ?>">
                    <span><?php _e('', 'MesajPaneliSMS'); ?></span>
                </td>
            </tr>
        </table>
    </div>

    <?php do_action('mesajpanelisms_gateway_settings_options_after') ?>
    <?php
}

// hook for Settings API for adding extra sections
add_action('wsa_form_bottom_mesajpanelisms_gateway', 'mesajpanelisms_settings_field_gateway');

